﻿using System;
using ClownFish;
using System.Collections.Generic;
using CodeRoboter.Utility;
using Model;
using ManagerService;

namespace Manager
{
    /// <summary>
    /// 表[T_Student]的Model[Student]业务逻辑类
    /// </summary>
    /// <remarks>作者：</remarks>
    /// <remarks>日期：</remarks>
    public class StudentManager
    {
        /// <summary>
        /// 读取表（对象）的列信息列表 （此方法用到了自定义属性类）
        /// </summary>
        /// <returns>列表（列名，列类型，列说明）</returns>
        public static List<object> Get_Student_TableColumnList()
        {
            List<object> lst_ColumnInfo = new List<object>();
            Type t = typeof(Student);
            foreach (var item in t.GetProperties())
            {
                var att = item.GetCustomAttributes(typeof(TableColumn_DIY_Attribute), false);
                if (att.Length > 0)
                    lst_ColumnInfo.Add(new { ColumnName = item.Name, ColumnTypeName = item.PropertyType.Name, ColumnNoteText = (att[0] as TableColumn_DIY_Attribute).ColumnNoteText });
                else
                    lst_ColumnInfo.Add(new { ColumnName = item.Name, ColumnTypeName = item.PropertyType.Name, ColumnNoteText = string.Empty });
            }
            return lst_ColumnInfo;
        }

        /// <summary>
        /// 是否存在
        /// </summary>
        /// <param name="student_id">学生编号</param>
        /// <returns>是否存在</returns>
        public static bool Exists_Student(int student_id)
        {
            return StudentManagerService.Exists_Student(student_id);
        }

        /// <summary>
        /// 新增信息
        /// </summary>
        /// <param name="student"></param>
        /// <returns>是否成功</returns>
        public static bool Add_Student(Student student)
        {
            return StudentManagerService.Insert_Student(student) > 0;
        }

        /// <summary>
        /// 修改信息
        /// </summary>
        /// <param name="student"></param>
        /// <returns>是否成功</returns>
        public static bool Modify_Student(Student student)
        {
            return StudentManagerService.Update_Student(student) > 0;
        }

        /// <summary>
        /// 删除信息
        /// </summary>
        /// <param name="student_id">学生编号</param>
        /// <returns>是否成功</returns>
        public static bool Remove_Student(int student_id)
        {
            return StudentManagerService.Delete_Student(student_id) > 0;
        }

        /// <summary>
        /// 根据条件获得对象
        /// </summary>
        /// <param name="student_id">学生编号</param>
        /// <returns>对象</returns>
        public static Student Get_Student(int student_id)
        {
            return StudentManagerService.GetModel_Student(student_id);
        }

        /// <summary>
        /// 根据获得对象分页列表
        /// </summary>
        /// <param name="student_id">学生编号</param>
        /// <returns>对象列表</returns>
        public static List<Student> GetList_Student(int student_id)
        {
            return StudentManagerService.GetList_Student(student_id);
        }

        /// <summary>
        /// 根据条件获得对象列表
        /// 说明：Pageinfo_对象_DIY pageinfo 类为自动生成，生成的类在数据访问层的下方
        /// </summary>
        /// <param name="PagingInfo">分页信息</param>
        /// <returns>分页对象列表</returns>
        public static List<Student> GetListPage_Student(Pageinfo_Student_DIY pageinfo)
        {
            return StudentManagerService.GetListPage_Student(pageinfo);
        }

        /// <summary>
        /// 根据条件获得对象列表
        /// </summary>
        /// <param name="PagingInfo">分页信息</param>
        /// <param name="student_id">学生编号</param>
        /// <returns>分页对象列表</returns>
        public static List<Student> GetListPage_Student(Pageinfo_Student_DIY pageinfo, int student_id)
        {
            pageinfo.Student_ID = student_id;
            return StudentManagerService.GetListPage_Student(pageinfo);
        }

    }
}
